var Lawtext = Lawtext || {};
Lawtext.sample_lawtext = `行政手続法
（平成五年法律第八十八号）

目次
  第一章　総則（第一条―第四条）
  第二章　申請に対する処分（第五条―第十一条）
  第三章　不利益処分
    第一節　通則（第十二条―第十四条）
    第二節　聴聞（第十五条―第二十八条）
    第三節　弁明の機会の付与（第二十九条―第三十一条）
  第四章　行政指導（第三十二条―第三十六条の二）
  第四章の二　処分等の求め（第三十六条の三）
  第五章　届出（第三十七条）
  第六章　意見公募手続等（第三十八条―第四十五条）
  第七章　補則（第四十六条）
  附則

      第一章　総則

  （目的等）
第一条　この法律は、処分、行政指導及び届出に関する手続並びに命令等を定める手続に関し、共通する事項を定めることによって、行政運営における公正の確保と透明性（行政上の意思決定について、その内容及び過程が国民にとって明らかであることをいう。第四十六条において同じ。）の向上を図り、もって国民の権利利益の保護に資することを目的とする。
２　処分、行政指導及び届出に関する手続並びに命令等を定める手続に関しこの法律に規定する事項について、他の法律に特別の定めがある場合は、その定めるところによる。

  （定義）
第二条　この法律において、次の各号に掲げる用語の意義は、当該各号に定めるところによる。
  一　法令　法律、法律に基づく命令（告示を含む。）、条例及び地方公共団体の執行機関の規則（規程を含む。以下「規則」という。）をいう。
  二　処分　行政庁の処分その他公権力の行使に当たる行為をいう。
  三　申請　法令に基づき、行政庁の許可、認可、免許その他の自己に対し何らかの利益を付与する処分（以下「許認可等」という。）を求める行為であって、当該行為に対して行政庁が諾否の応答をすべきこととされているものをいう。
  四　不利益処分　行政庁が、法令に基づき、特定の者を名あて人として、直接に、これに義務を課し、又はその権利を制限する処分をいう。ただし、次のいずれかに該当するものを除く。
    イ　事実上の行為及び事実上の行為をするに当たりその範囲、時期等を明らかにするために法令上必要とされている手続としての処分
    ロ　申請により求められた許認可等を拒否する処分その他申請に基づき当該申請をした者を名あて人としてされる処分
    ハ　名あて人となるべき者の同意の下にすることとされている処分
    ニ　許認可等の効力を失わせる処分であって、当該許認可等の基礎となった事実が消滅した旨の届出があったことを理由としてされるもの
  五　行政機関　次に掲げる機関をいう。
    イ　法律の規定に基づき内閣に置かれる機関若しくは内閣の所轄の下に置かれる機関、宮内庁、内閣府設置法（平成十一年法律第八十九号）第四十九条第一項若しくは第二項に規定する機関、国家行政組織法（昭和二十三年法律第百二十号）第三条第二項に規定する機関、会計検査院若しくはこれらに置かれる機関又はこれらの機関の職員であって法律上独立に権限を行使することを認められた職員
    ロ　地方公共団体の機関（議会を除く。）
  六　行政指導　行政機関がその任務又は所掌事務の範囲内において一定の行政目的を実現するため特定の者に一定の作為又は不作為を求める指導、勧告、助言その他の行為であって処分に該当しないものをいう。
  七　届出　行政庁に対し一定の事項の通知をする行為（申請に該当するものを除く。）であって、法令により直接に当該通知が義務付けられているもの（自己の期待する一定の法律上の効果を発生させるためには当該通知をすべきこととされているものを含む。）をいう。
  八　命令等　内閣又は行政機関が定める次に掲げるものをいう。
    イ　法律に基づく命令（処分の要件を定める告示を含む。次条第二項において単に「命令」という。）又は規則
    ロ　審査基準（申請により求められた許認可等をするかどうかをその法令の定めに従って判断するために必要とされる基準をいう。以下同じ。）
    ハ　処分基準（不利益処分をするかどうか又はどのような不利益処分とするかについてその法令の定めに従って判断するために必要とされる基準をいう。以下同じ。）
    ニ　行政指導指針（同一の行政目的を実現するため一定の条件に該当する複数の者に対し行政指導をしようとするときにこれらの行政指導に共通してその内容となるべき事項をいう。以下同じ。）

  （適用除外）
第三条　次に掲げる処分及び行政指導については、次章から第四章の二までの規定は、適用しない。
  一　国会の両院若しくは一院又は議会の議決によってされる処分
  二　裁判所若しくは裁判官の裁判により、又は裁判の執行としてされる処分
  三　国会の両院若しくは一院若しくは議会の議決を経て、又はこれらの同意若しくは承認を得た上でされるべきものとされている処分
  四　検査官会議で決すべきものとされている処分及び会計検査の際にされる行政指導
  五　刑事事件に関する法令に基づいて検察官、検察事務官又は司法警察職員がする処分及び行政指導
  六　国税又は地方税の犯則事件に関する法令（他の法令において準用する場合を含む。）に基づいて国税庁長官、国税局長、税務署長、収税官吏、税関長、税関職員又は徴税吏員（他の法令の規定に基づいてこれらの職員の職務を行う者を含む。）がする処分及び行政指導並びに金融商品取引の犯則事件に関する法令（他の法令において準用する場合を含む。）に基づいて証券取引等監視委員会、その職員（当該法令においてその職員とみなされる者を含む。）、財務局長又は財務支局長がする処分及び行政指導
  七　学校、講習所、訓練所又は研修所において、教育、講習、訓練又は研修の目的を達成するために、学生、生徒、児童若しくは幼児若しくはこれらの保護者、講習生、訓練生又は研修生に対してされる処分及び行政指導
  八　刑務所、少年刑務所、拘置所、留置施設、海上保安留置施設、少年院、少年鑑別所又は婦人補導院において、収容の目的を達成するためにされる処分及び行政指導
  九　公務員（国家公務員法（昭和二十二年法律第百二十号）第二条第一項に規定する国家公務員及び地方公務員法（昭和二十五年法律第二百六十一号）第三条第一項に規定する地方公務員をいう。以下同じ。）又は公務員であった者に対してその職務又は身分に関してされる処分及び行政指導
  十　外国人の出入国、難民の認定又は帰化に関する処分及び行政指導
  十一　専ら人の学識技能に関する試験又は検定の結果についての処分
  十二　相反する利害を有する者の間の利害の調整を目的として法令の規定に基づいてされる裁定その他の処分（その双方を名宛人とするものに限る。）及び行政指導
  十三　公衆衛生、環境保全、防疫、保安その他の公益に関わる事象が発生し又は発生する可能性のある現場において警察官若しくは海上保安官又はこれらの公益を確保するために行使すべき権限を法律上直接に与えられたその他の職員によってされる処分及び行政指導
  十四　報告又は物件の提出を命ずる処分その他その職務の遂行上必要な情報の収集を直接の目的としてされる処分及び行政指導
  十五　審査請求、再調査の請求その他の不服申立てに対する行政庁の裁決、決定その他の処分
  十六　前号に規定する処分の手続又は第三章に規定する聴聞若しくは弁明の機会の付与の手続その他の意見陳述のための手続において法令に基づいてされる処分及び行政指導
２　次に掲げる命令等を定める行為については、第六章の規定は、適用しない。
  一　法律の施行期日について定める政令
  二　恩赦に関する命令
  三　命令又は規則を定める行為が処分に該当する場合における当該命令又は規則
  四　法律の規定に基づき施設、区間、地域その他これらに類するものを指定する命令又は規則
  五　公務員の給与、勤務時間その他の勤務条件について定める命令等
  六　審査基準、処分基準又は行政指導指針であって、法令の規定により若しくは慣行として、又は命令等を定める機関の判断により公にされるもの以外のもの
３　第一項各号及び前項各号に掲げるもののほか、地方公共団体の機関がする処分（その根拠となる規定が条例又は規則に置かれているものに限る。）及び行政指導、地方公共団体の機関に対する届出（前条第七号の通知の根拠となる規定が条例又は規則に置かれているものに限る。）並びに地方公共団体の機関が命令等を定める行為については、次章から第六章までの規定は、適用しない。

  （国の機関等に対する処分等の適用除外）
第四条　国の機関又は地方公共団体若しくはその機関に対する処分（これらの機関又は団体がその固有の資格において当該処分の名あて人となるものに限る。）及び行政指導並びにこれらの機関又は団体がする届出（これらの機関又は団体がその固有の資格においてすべきこととされているものに限る。）については、この法律の規定は、適用しない。
２　次の各号のいずれかに該当する法人に対する処分であって、当該法人の監督に関する法律の特別の規定に基づいてされるもの（当該法人の解散を命じ、若しくは設立に関する認可を取り消す処分又は当該法人の役員若しくは当該法人の業務に従事する者の解任を命ずる処分を除く。）については、次章及び第三章の規定は、適用しない。
  一　法律により直接に設立された法人又は特別の法律により特別の設立行為をもって設立された法人
  二　特別の法律により設立され、かつ、その設立に関し行政庁の認可を要する法人のうち、その行う業務が国又は地方公共団体の行政運営と密接な関連を有するものとして政令で定める法人
３　行政庁が法律の規定に基づく試験、検査、検定、登録その他の行政上の事務について当該法律に基づきその全部又は一部を行わせる者を指定した場合において、その指定を受けた者（その者が法人である場合にあっては、その役員）又は職員その他の者が当該事務に従事することに関し公務に従事する職員とみなされるときは、その指定を受けた者に対し当該法律に基づいて当該事務に関し監督上される処分（当該指定を取り消す処分、その指定を受けた者が法人である場合におけるその役員の解任を命ずる処分又はその指定を受けた者の当該事務に従事する者の解任を命ずる処分を除く。）については、次章及び第三章の規定は、適用しない。
４　次に掲げる命令等を定める行為については、第六章の規定は、適用しない。
  一　国又は地方公共団体の機関の設置、所掌事務の範囲その他の組織について定める命令等
  二　皇室典範（昭和二十二年法律第三号）第二十六条の皇統譜について定める命令等
  三　公務員の礼式、服制、研修、教育訓練、表彰及び報償並びに公務員の間における競争試験について定める命令等
  四　国又は地方公共団体の予算、決算及び会計について定める命令等（入札の参加者の資格、入札保証金その他の国又は地方公共団体の契約の相手方又は相手方になろうとする者に係る事項を定める命令等を除く。）並びに国又は地方公共団体の財産及び物品の管理について定める命令等（国又は地方公共団体が財産及び物品を貸し付け、交換し、売り払い、譲与し、信託し、若しくは出資の目的とし、又はこれらに私権を設定することについて定める命令等であって、これらの行為の相手方又は相手方になろうとする者に係る事項を定めるものを除く。）
  五　会計検査について定める命令等
  六　国の機関相互間の関係について定める命令等並びに地方自治法（昭和二十二年法律第六十七号）第二編第十一章に規定する国と普通地方公共団体との関係及び普通地方公共団体相互間の関係その他の国と地方公共団体との関係及び地方公共団体相互間の関係について定める命令等（第一項の規定によりこの法律の規定を適用しないこととされる処分に係る命令等を含む。）
  七　第二項各号に規定する法人の役員及び職員、業務の範囲、財務及び会計その他の組織、運営及び管理について定める命令等（これらの法人に対する処分であって、これらの法人の解散を命じ、若しくは設立に関する認可を取り消す処分又はこれらの法人の役員若しくはこれらの法人の業務に従事する者の解任を命ずる処分に係る命令等を除く。）

      第二章　申請に対する処分

  （審査基準）
第五条　行政庁は、審査基準を定めるものとする。
２　行政庁は、審査基準を定めるに当たっては、許認可等の性質に照らしてできる限り具体的なものとしなければならない。
３　行政庁は、行政上特別の支障があるときを除き、法令により申請の提出先とされている機関の事務所における備付けその他の適当な方法により審査基準を公にしておかなければならない。

  （標準処理期間）
第六条　行政庁は、申請がその事務所に到達してから当該申請に対する処分をするまでに通常要すべき標準的な期間（法令により当該行政庁と異なる機関が当該申請の提出先とされている場合は、併せて、当該申請が当該提出先とされている機関の事務所に到達してから当該行政庁の事務所に到達するまでに通常要すべき標準的な期間）を定めるよう努めるとともに、これを定めたときは、これらの当該申請の提出先とされている機関の事務所における備付けその他の適当な方法により公にしておかなければならない。

  （申請に対する審査、応答）
第七条　行政庁は、申請がその事務所に到達したときは遅滞なく当該申請の審査を開始しなければならず、かつ、申請書の記載事項に不備がないこと、申請書に必要な書類が添付されていること、申請をすることができる期間内にされたものであることその他の法令に定められた申請の形式上の要件に適合しない申請については、速やかに、申請をした者（以下「申請者」という。）に対し相当の期間を定めて当該申請の補正を求め、又は当該申請により求められた許認可等を拒否しなければならない。

  （理由の提示）
第八条　行政庁は、申請により求められた許認可等を拒否する処分をする場合は、申請者に対し、同時に、当該処分の理由を示さなければならない。ただし、法令に定められた許認可等の要件又は公にされた審査基準が数量的指標その他の客観的指標により明確に定められている場合であって、当該申請がこれらに適合しないことが申請書の記載又は添付書類その他の申請の内容から明らかであるときは、申請者の求めがあったときにこれを示せば足りる。
２　前項本文に規定する処分を書面でするときは、同項の理由は、書面により示さなければならない。

  （情報の提供）
第九条　行政庁は、申請者の求めに応じ、当該申請に係る審査の進行状況及び当該申請に対する処分の時期の見通しを示すよう努めなければならない。
２　行政庁は、申請をしようとする者又は申請者の求めに応じ、申請書の記載及び添付書類に関する事項その他の申請に必要な情報の提供に努めなければならない。

  （公聴会の開催等）
第十条　行政庁は、申請に対する処分であって、申請者以外の者の利害を考慮すべきことが当該法令において許認可等の要件とされているものを行う場合には、必要に応じ、公聴会の開催その他の適当な方法により当該申請者以外の者の意見を聴く機会を設けるよう努めなければならない。

  （複数の行政庁が関与する処分）
第十一条　行政庁は、申請の処理をするに当たり、他の行政庁において同一の申請者からされた関連する申請が審査中であることをもって自らすべき許認可等をするかどうかについての審査又は判断を殊更に遅延させるようなことをしてはならない。
２　一の申請又は同一の申請者からされた相互に関連する複数の申請に対する処分について複数の行政庁が関与する場合においては、当該複数の行政庁は、必要に応じ、相互に連絡をとり、当該申請者からの説明の聴取を共同して行う等により審査の促進に努めるものとする。

      第三章　不利益処分

        第一節　通則

  （処分の基準）
第十二条　行政庁は、処分基準を定め、かつ、これを公にしておくよう努めなければならない。
２　行政庁は、処分基準を定めるに当たっては、不利益処分の性質に照らしてできる限り具体的なものとしなければならない。

  （不利益処分をしようとする場合の手続）
第十三条　行政庁は、不利益処分をしようとする場合には、次の各号の区分に従い、この章の定めるところにより、当該不利益処分の名あて人となるべき者について、当該各号に定める意見陳述のための手続を執らなければならない。
  一　次のいずれかに該当するとき　聴聞
    イ　許認可等を取り消す不利益処分をしようとするとき。
    ロ　イに規定するもののほか、名あて人の資格又は地位を直接にはく奪する不利益処分をしようとするとき。
    ハ　名あて人が法人である場合におけるその役員の解任を命ずる不利益処分、名あて人の業務に従事する者の解任を命ずる不利益処分又は名あて人の会員である者の除名を命ずる不利益処分をしようとするとき。
    ニ　イからハまでに掲げる場合以外の場合であって行政庁が相当と認めるとき。
  二　前号イからニまでのいずれにも該当しないとき　弁明の機会の付与
２　次の各号のいずれかに該当するときは、前項の規定は、適用しない。
  一　公益上、緊急に不利益処分をする必要があるため、前項に規定する意見陳述のための手続を執ることができないとき。
  二　法令上必要とされる資格がなかったこと又は失われるに至ったことが判明した場合に必ずすることとされている不利益処分であって、その資格の不存在又は喪失の事実が裁判所の判決書又は決定書、一定の職に就いたことを証する当該任命権者の書類その他の客観的な資料により直接証明されたものをしようとするとき。
  三　施設若しくは設備の設置、維持若しくは管理又は物の製造、販売その他の取扱いについて遵守すべき事項が法令において技術的な基準をもって明確にされている場合において、専ら当該基準が充足されていないことを理由として当該基準に従うべきことを命ずる不利益処分であってその不充足の事実が計測、実験その他客観的な認定方法によって確認されたものをしようとするとき。
  四　納付すべき金銭の額を確定し、一定の額の金銭の納付を命じ、又は金銭の給付決定の取消しその他の金銭の給付を制限する不利益処分をしようとするとき。
  五　当該不利益処分の性質上、それによって課される義務の内容が著しく軽微なものであるため名あて人となるべき者の意見をあらかじめ聴くことを要しないものとして政令で定める処分をしようとするとき。

  （不利益処分の理由の提示）
第十四条　行政庁は、不利益処分をする場合には、その名あて人に対し、同時に、当該不利益処分の理由を示さなければならない。ただし、当該理由を示さないで処分をすべき差し迫った必要がある場合は、この限りでない。
２　行政庁は、前項ただし書の場合においては、当該名あて人の所在が判明しなくなったときその他処分後において理由を示すことが困難な事情があるときを除き、処分後相当の期間内に、同項の理由を示さなければならない。
３　不利益処分を書面でするときは、前二項の理由は、書面により示さなければならない。

        第二節　聴聞

  （聴聞の通知の方式）
第十五条　行政庁は、聴聞を行うに当たっては、聴聞を行うべき期日までに相当な期間をおいて、不利益処分の名あて人となるべき者に対し、次に掲げる事項を書面により通知しなければならない。
  一　予定される不利益処分の内容及び根拠となる法令の条項
  二　不利益処分の原因となる事実
  三　聴聞の期日及び場所
  四　聴聞に関する事務を所掌する組織の名称及び所在地
２　前項の書面においては、次に掲げる事項を教示しなければならない。
  一　聴聞の期日に出頭して意見を述べ、及び証拠書類又は証拠物（以下「証拠書類等」という。）を提出し、又は聴聞の期日への出頭に代えて陳述書及び証拠書類等を提出することができること。
  二　聴聞が終結する時までの間、当該不利益処分の原因となる事実を証する資料の閲覧を求めることができること。
３　行政庁は、不利益処分の名あて人となるべき者の所在が判明しない場合においては、第一項の規定による通知を、その者の氏名、同項第三号及び第四号に掲げる事項並びに当該行政庁が同項各号に掲げる事項を記載した書面をいつでもその者に交付する旨を当該行政庁の事務所の掲示場に掲示することによって行うことができる。この場合においては、掲示を始めた日から二週間を経過したときに、当該通知がその者に到達したものとみなす。

  （代理人）
第十六条　前条第一項の通知を受けた者（同条第三項後段の規定により当該通知が到達したものとみなされる者を含む。以下「当事者」という。）は、代理人を選任することができる。
２　代理人は、各自、当事者のために、聴聞に関する一切の行為をすることができる。
３　代理人の資格は、書面で証明しなければならない。
４　代理人がその資格を失ったときは、当該代理人を選任した当事者は、書面でその旨を行政庁に届け出なければならない。

  （参加人）
第十七条　第十九条の規定により聴聞を主宰する者（以下「主宰者」という。）は、必要があると認めるときは、当事者以外の者であって当該不利益処分の根拠となる法令に照らし当該不利益処分につき利害関係を有するものと認められる者（同条第二項第六号において「関係人」という。）に対し、当該聴聞に関する手続に参加することを求め、又は当該聴聞に関する手続に参加することを許可することができる。
２　前項の規定により当該聴聞に関する手続に参加する者（以下「参加人」という。）は、代理人を選任することができる。
３　前条第二項から第四項までの規定は、前項の代理人について準用する。この場合において、同条第二項及び第四項中「当事者」とあるのは、「参加人」と読み替えるものとする。

  （文書等の閲覧）
第十八条　当事者及び当該不利益処分がされた場合に自己の利益を害されることとなる参加人（以下この条及び第二十四条第三項において「当事者等」という。）は、聴聞の通知があった時から聴聞が終結する時までの間、行政庁に対し、当該事案についてした調査の結果に係る調書その他の当該不利益処分の原因となる事実を証する資料の閲覧を求めることができる。この場合において、行政庁は、第三者の利益を害するおそれがあるときその他正当な理由があるときでなければ、その閲覧を拒むことができない。
２　前項の規定は、当事者等が聴聞の期日における審理の進行に応じて必要となった資料の閲覧を更に求めることを妨げない。
３　行政庁は、前二項の閲覧について日時及び場所を指定することができる。

  （聴聞の主宰）
第十九条　聴聞は、行政庁が指名する職員その他政令で定める者が主宰する。
２　次の各号のいずれかに該当する者は、聴聞を主宰することができない。
  一　当該聴聞の当事者又は参加人
  二　前号に規定する者の配偶者、四親等内の親族又は同居の親族
  三　第一号に規定する者の代理人又は次条第三項に規定する補佐人
  四　前三号に規定する者であった者
  五　第一号に規定する者の後見人、後見監督人、保佐人、保佐監督人、補助人又は補助監督人
  六　参加人以外の関係人

  （聴聞の期日における審理の方式）
第二十条　主宰者は、最初の聴聞の期日の冒頭において、行政庁の職員に、予定される不利益処分の内容及び根拠となる法令の条項並びにその原因となる事実を聴聞の期日に出頭した者に対し説明させなければならない。
２　当事者又は参加人は、聴聞の期日に出頭して、意見を述べ、及び証拠書類等を提出し、並びに主宰者の許可を得て行政庁の職員に対し質問を発することができる。
３　前項の場合において、当事者又は参加人は、主宰者の許可を得て、補佐人とともに出頭することができる。
４　主宰者は、聴聞の期日において必要があると認めるときは、当事者若しくは参加人に対し質問を発し、意見の陳述若しくは証拠書類等の提出を促し、又は行政庁の職員に対し説明を求めることができる。
５　主宰者は、当事者又は参加人の一部が出頭しないときであっても、聴聞の期日における審理を行うことができる。
６　聴聞の期日における審理は、行政庁が公開することを相当と認めるときを除き、公開しない。

  （陳述書等の提出）
第二十一条　当事者又は参加人は、聴聞の期日への出頭に代えて、主宰者に対し、聴聞の期日までに陳述書及び証拠書類等を提出することができる。
２　主宰者は、聴聞の期日に出頭した者に対し、その求めに応じて、前項の陳述書及び証拠書類等を示すことができる。

  （続行期日の指定）
第二十二条　主宰者は、聴聞の期日における審理の結果、なお聴聞を続行する必要があると認めるときは、さらに新たな期日を定めることができる。
２　前項の場合においては、当事者及び参加人に対し、あらかじめ、次回の聴聞の期日及び場所を書面により通知しなければならない。ただし、聴聞の期日に出頭した当事者及び参加人に対しては、当該聴聞の期日においてこれを告知すれば足りる。
３　第十五条第三項の規定は、前項本文の場合において、当事者又は参加人の所在が判明しないときにおける通知の方法について準用する。この場合において、同条第三項中「不利益処分の名あて人となるべき者」とあるのは「当事者又は参加人」と、「掲示を始めた日から二週間を経過したとき」とあるのは「掲示を始めた日から二週間を経過したとき（同一の当事者又は参加人に対する二回目以降の通知にあっては、掲示を始めた日の翌日）」と読み替えるものとする。

  （当事者の不出頭等の場合における聴聞の終結）
第二十三条　主宰者は、当事者の全部若しくは一部が正当な理由なく聴聞の期日に出頭せず、かつ、第二十一条第一項に規定する陳述書若しくは証拠書類等を提出しない場合、又は参加人の全部若しくは一部が聴聞の期日に出頭しない場合には、これらの者に対し改めて意見を述べ、及び証拠書類等を提出する機会を与えることなく、聴聞を終結することができる。
２　主宰者は、前項に規定する場合のほか、当事者の全部又は一部が聴聞の期日に出頭せず、かつ、第二十一条第一項に規定する陳述書又は証拠書類等を提出しない場合において、これらの者の聴聞の期日への出頭が相当期間引き続き見込めないときは、これらの者に対し、期限を定めて陳述書及び証拠書類等の提出を求め、当該期限が到来したときに聴聞を終結することとすることができる。

  （聴聞調書及び報告書）
第二十四条　主宰者は、聴聞の審理の経過を記載した調書を作成し、当該調書において、不利益処分の原因となる事実に対する当事者及び参加人の陳述の要旨を明らかにしておかなければならない。
２　前項の調書は、聴聞の期日における審理が行われた場合には各期日ごとに、当該審理が行われなかった場合には聴聞の終結後速やかに作成しなければならない。
３　主宰者は、聴聞の終結後速やかに、不利益処分の原因となる事実に対する当事者等の主張に理由があるかどうかについての意見を記載した報告書を作成し、第一項の調書とともに行政庁に提出しなければならない。
４　当事者又は参加人は、第一項の調書及び前項の報告書の閲覧を求めることができる。

  （聴聞の再開）
第二十五条　行政庁は、聴聞の終結後に生じた事情にかんがみ必要があると認めるときは、主宰者に対し、前条第三項の規定により提出された報告書を返戻して聴聞の再開を命ずることができる。第二十二条第二項本文及び第三項の規定は、この場合について準用する。

  （聴聞を経てされる不利益処分の決定）
第二十六条　行政庁は、不利益処分の決定をするときは、第二十四条第一項の調書の内容及び同条第三項の報告書に記載された主宰者の意見を十分に参酌してこれをしなければならない。

  （審査請求の制限）
第二十七条　この節の規定に基づく処分又はその不作為については、審査請求をすることができない。

  （役員等の解任等を命ずる不利益処分をしようとする場合の聴聞等の特例）
第二十八条　第十三条第一項第一号ハに該当する不利益処分に係る聴聞において第十五条第一項の通知があった場合におけるこの節の規定の適用については、名あて人である法人の役員、名あて人の業務に従事する者又は名あて人の会員である者（当該処分において解任し又は除名すべきこととされている者に限る。）は、同項の通知を受けた者とみなす。
２　前項の不利益処分のうち名あて人である法人の役員又は名あて人の業務に従事する者（以下この項において「役員等」という。）の解任を命ずるものに係る聴聞が行われた場合においては、当該処分にその名あて人が従わないことを理由として法令の規定によりされる当該役員等を解任する不利益処分については、第十三条第一項の規定にかかわらず、行政庁は、当該役員等について聴聞を行うことを要しない。

        第三節　弁明の機会の付与

  （弁明の機会の付与の方式）
第二十九条　弁明は、行政庁が口頭ですることを認めたときを除き、弁明を記載した書面（以下「弁明書」という。）を提出してするものとする。
２　弁明をするときは、証拠書類等を提出することができる。

  （弁明の機会の付与の通知の方式）
第三十条　行政庁は、弁明書の提出期限（口頭による弁明の機会の付与を行う場合には、その日時）までに相当な期間をおいて、不利益処分の名あて人となるべき者に対し、次に掲げる事項を書面により通知しなければならない。
  一　予定される不利益処分の内容及び根拠となる法令の条項
  二　不利益処分の原因となる事実
  三　弁明書の提出先及び提出期限（口頭による弁明の機会の付与を行う場合には、その旨並びに出頭すべき日時及び場所）

  （聴聞に関する手続の準用）
第三十一条　第十五条第三項及び第十六条の規定は、弁明の機会の付与について準用する。この場合において、第十五条第三項中「第一項」とあるのは「第三十条」と、「同項第三号及び第四号」とあるのは「同条第三号」と、第十六条第一項中「前条第一項」とあるのは「第三十条」と、「同条第三項後段」とあるのは「第三十一条において準用する第十五条第三項後段」と読み替えるものとする。

      第四章　行政指導

  （行政指導の一般原則）
第三十二条　行政指導にあっては、行政指導に携わる者は、いやしくも当該行政機関の任務又は所掌事務の範囲を逸脱してはならないこと及び行政指導の内容があくまでも相手方の任意の協力によってのみ実現されるものであることに留意しなければならない。
２　行政指導に携わる者は、その相手方が行政指導に従わなかったことを理由として、不利益な取扱いをしてはならない。

  （申請に関連する行政指導）
第三十三条　申請の取下げ又は内容の変更を求める行政指導にあっては、行政指導に携わる者は、申請者が当該行政指導に従う意思がない旨を表明したにもかかわらず当該行政指導を継続すること等により当該申請者の権利の行使を妨げるようなことをしてはならない。

  （許認可等の権限に関連する行政指導）
第三十四条　許認可等をする権限又は許認可等に基づく処分をする権限を有する行政機関が、当該権限を行使することができない場合又は行使する意思がない場合においてする行政指導にあっては、行政指導に携わる者は、当該権限を行使し得る旨を殊更に示すことにより相手方に当該行政指導に従うことを余儀なくさせるようなことをしてはならない。

  （行政指導の方式）
第三十五条　行政指導に携わる者は、その相手方に対して、当該行政指導の趣旨及び内容並びに責任者を明確に示さなければならない。
２　行政指導に携わる者は、当該行政指導をする際に、行政機関が許認可等をする権限又は許認可等に基づく処分をする権限を行使し得る旨を示すときは、その相手方に対して、次に掲げる事項を示さなければならない。
  一　当該権限を行使し得る根拠となる法令の条項
  二　前号の条項に規定する要件
  三　当該権限の行使が前号の要件に適合する理由
３　行政指導が口頭でされた場合において、その相手方から前二項に規定する事項を記載した書面の交付を求められたときは、当該行政指導に携わる者は、行政上特別の支障がない限り、これを交付しなければならない。
４　前項の規定は、次に掲げる行政指導については、適用しない。
  一　相手方に対しその場において完了する行為を求めるもの
  二　既に文書（前項の書面を含む。）又は電磁的記録（電子的方式、磁気的方式その他人の知覚によっては認識することができない方式で作られる記録であって、電子計算機による情報処理の用に供されるものをいう。）によりその相手方に通知されている事項と同一の内容を求めるもの

  （複数の者を対象とする行政指導）
第三十六条　同一の行政目的を実現するため一定の条件に該当する複数の者に対し行政指導をしようとするときは、行政機関は、あらかじめ、事案に応じ、行政指導指針を定め、かつ、行政上特別の支障がない限り、これを公表しなければならない。

  （行政指導の中止等の求め）
第三十六条の二　法令に違反する行為の是正を求める行政指導（その根拠となる規定が法律に置かれているものに限る。）の相手方は、当該行政指導が当該法律に規定する要件に適合しないと思料するときは、当該行政指導をした行政機関に対し、その旨を申し出て、当該行政指導の中止その他必要な措置をとることを求めることができる。ただし、当該行政指導がその相手方について弁明その他意見陳述のための手続を経てされたものであるときは、この限りでない。
２　前項の申出は、次に掲げる事項を記載した申出書を提出してしなければならない。
  一　申出をする者の氏名又は名称及び住所又は居所
  二　当該行政指導の内容
  三　当該行政指導がその根拠とする法律の条項
  四　前号の条項に規定する要件
  五　当該行政指導が前号の要件に適合しないと思料する理由
  六　その他参考となる事項
３　当該行政機関は、第一項の規定による申出があったときは、必要な調査を行い、当該行政指導が当該法律に規定する要件に適合しないと認めるときは、当該行政指導の中止その他必要な措置をとらなければならない。

      第四章の二　処分等の求め

第三十六条の三　何人も、法令に違反する事実がある場合において、その是正のためにされるべき処分又は行政指導（その根拠となる規定が法律に置かれているものに限る。）がされていないと思料するときは、当該処分をする権限を有する行政庁又は当該行政指導をする権限を有する行政機関に対し、その旨を申し出て、当該処分又は行政指導をすることを求めることができる。
２　前項の申出は、次に掲げる事項を記載した申出書を提出してしなければならない。
  一　申出をする者の氏名又は名称及び住所又は居所
  二　法令に違反する事実の内容
  三　当該処分又は行政指導の内容
  四　当該処分又は行政指導の根拠となる法令の条項
  五　当該処分又は行政指導がされるべきであると思料する理由
  六　その他参考となる事項
３　当該行政庁又は行政機関は、第一項の規定による申出があったときは、必要な調査を行い、その結果に基づき必要があると認めるときは、当該処分又は行政指導をしなければならない。

      第五章　届出

  （届出）
第三十七条　届出が届出書の記載事項に不備がないこと、届出書に必要な書類が添付されていることその他の法令に定められた届出の形式上の要件に適合している場合は、当該届出が法令により当該届出の提出先とされている機関の事務所に到達したときに、当該届出をすべき手続上の義務が履行されたものとする。

      第六章　意見公募手続等

  （命令等を定める場合の一般原則）
第三十八条　命令等を定める機関（閣議の決定により命令等が定められる場合にあっては、当該命令等の立案をする各大臣。以下「命令等制定機関」という。）は、命令等を定めるに当たっては、当該命令等がこれを定める根拠となる法令の趣旨に適合するものとなるようにしなければならない。
２　命令等制定機関は、命令等を定めた後においても、当該命令等の規定の実施状況、社会経済情勢の変化等を勘案し、必要に応じ、当該命令等の内容について検討を加え、その適正を確保するよう努めなければならない。

  （意見公募手続）
第三十九条　命令等制定機関は、命令等を定めようとする場合には、当該命令等の案（命令等で定めようとする内容を示すものをいう。以下同じ。）及びこれに関連する資料をあらかじめ公示し、意見（情報を含む。以下同じ。）の提出先及び意見の提出のための期間（以下「意見提出期間」という。）を定めて広く一般の意見を求めなければならない。
２　前項の規定により公示する命令等の案は、具体的かつ明確な内容のものであって、かつ、当該命令等の題名及び当該命令等を定める根拠となる法令の条項が明示されたものでなければならない。
３　第一項の規定により定める意見提出期間は、同項の公示の日から起算して三十日以上でなければならない。
４　次の各号のいずれかに該当するときは、第一項の規定は、適用しない。
  一　公益上、緊急に命令等を定める必要があるため、第一項の規定による手続（以下「意見公募手続」という。）を実施することが困難であるとき。
  二　納付すべき金銭について定める法律の制定又は改正により必要となる当該金銭の額の算定の基礎となるべき金額及び率並びに算定方法についての命令等その他当該法律の施行に関し必要な事項を定める命令等を定めようとするとき。
  三　予算の定めるところにより金銭の給付決定を行うために必要となる当該金銭の額の算定の基礎となるべき金額及び率並びに算定方法その他の事項を定める命令等を定めようとするとき。
  四　法律の規定により、内閣府設置法第四十九条第一項若しくは第二項若しくは国家行政組織法第三条第二項に規定する委員会又は内閣府設置法第三十七条若しくは第五十四条若しくは国家行政組織法第八条に規定する機関（以下「委員会等」という。）の議を経て定めることとされている命令等であって、相反する利害を有する者の間の利害の調整を目的として、法律又は政令の規定により、これらの者及び公益をそれぞれ代表する委員をもって組織される委員会等において審議を行うこととされているものとして政令で定める命令等を定めようとするとき。
  五　他の行政機関が意見公募手続を実施して定めた命令等と実質的に同一の命令等を定めようとするとき。
  六　法律の規定に基づき法令の規定の適用又は準用について必要な技術的読替えを定める命令等を定めようとするとき。
  七　命令等を定める根拠となる法令の規定の削除に伴い当然必要とされる当該命令等の廃止をしようとするとき。
  八　他の法令の制定又は改廃に伴い当然必要とされる規定の整理その他の意見公募手続を実施することを要しない軽微な変更として政令で定めるものを内容とする命令等を定めようとするとき。

  （意見公募手続の特例）
第四十条　命令等制定機関は、命令等を定めようとする場合において、三十日以上の意見提出期間を定めることができないやむを得ない理由があるときは、前条第三項の規定にかかわらず、三十日を下回る意見提出期間を定めることができる。この場合においては、当該命令等の案の公示の際その理由を明らかにしなければならない。
２　命令等制定機関は、委員会等の議を経て命令等を定めようとする場合（前条第四項第四号に該当する場合を除く。）において、当該委員会等が意見公募手続に準じた手続を実施したときは、同条第一項の規定にかかわらず、自ら意見公募手続を実施することを要しない。

  （意見公募手続の周知等）
第四十一条　命令等制定機関は、意見公募手続を実施して命令等を定めるに当たっては、必要に応じ、当該意見公募手続の実施について周知するよう努めるとともに、当該意見公募手続の実施に関連する情報の提供に努めるものとする。

  （提出意見の考慮）
第四十二条　命令等制定機関は、意見公募手続を実施して命令等を定める場合には、意見提出期間内に当該命令等制定機関に対し提出された当該命令等の案についての意見（以下「提出意見」という。）を十分に考慮しなければならない。

  （結果の公示等）
第四十三条　命令等制定機関は、意見公募手続を実施して命令等を定めた場合には、当該命令等の公布（公布をしないものにあっては、公にする行為。第五項において同じ。）と同時期に、次に掲げる事項を公示しなければならない。
  一　命令等の題名
  二　命令等の案の公示の日
  三　提出意見（提出意見がなかった場合にあっては、その旨）
  四　提出意見を考慮した結果（意見公募手続を実施した命令等の案と定めた命令等との差異を含む。）及びその理由
２　命令等制定機関は、前項の規定にかかわらず、必要に応じ、同項第三号の提出意見に代えて、当該提出意見を整理又は要約したものを公示することができる。この場合においては、当該公示の後遅滞なく、当該提出意見を当該命令等制定機関の事務所における備付けその他の適当な方法により公にしなければならない。
３　命令等制定機関は、前二項の規定により提出意見を公示し又は公にすることにより第三者の利益を害するおそれがあるとき、その他正当な理由があるときは、当該提出意見の全部又は一部を除くことができる。
４　命令等制定機関は、意見公募手続を実施したにもかかわらず命令等を定めないこととした場合には、その旨（別の命令等の案について改めて意見公募手続を実施しようとする場合にあっては、その旨を含む。）並びに第一項第一号及び第二号に掲げる事項を速やかに公示しなければならない。
５　命令等制定機関は、第三十九条第四項各号のいずれかに該当することにより意見公募手続を実施しないで命令等を定めた場合には、当該命令等の公布と同時期に、次に掲げる事項を公示しなければならない。ただし、第一号に掲げる事項のうち命令等の趣旨については、同項第一号から第四号までのいずれかに該当することにより意見公募手続を実施しなかった場合において、当該命令等自体から明らかでないときに限る。
  一　命令等の題名及び趣旨
  二　意見公募手続を実施しなかった旨及びその理由

  （準用）
第四十四条　第四十二条の規定は第四十条第二項に該当することにより命令等制定機関が自ら意見公募手続を実施しないで命令等を定める場合について、前条第一項から第三項までの規定は第四十条第二項に該当することにより命令等制定機関が自ら意見公募手続を実施しないで命令等を定めた場合について、前条第四項の規定は第四十条第二項に該当することにより命令等制定機関が自ら意見公募手続を実施しないで命令等を定めないこととした場合について準用する。この場合において、第四十二条中「当該命令等制定機関」とあるのは「委員会等」と、前条第一項第二号中「命令等の案の公示の日」とあるのは「委員会等が命令等の案について公示に準じた手続を実施した日」と、同項第四号中「意見公募手続を実施した」とあるのは「委員会等が意見公募手続に準じた手続を実施した」と読み替えるものとする。

  （公示の方法）
第四十五条　第三十九条第一項並びに第四十三条第一項（前条において読み替えて準用する場合を含む。）、第四項（前条において準用する場合を含む。）及び第五項の規定による公示は、電子情報処理組織を使用する方法その他の情報通信の技術を利用する方法により行うものとする。
２　前項の公示に関し必要な事項は、総務大臣が定める。

      第七章　補則

  （地方公共団体の措置）
第四十六条　地方公共団体は、第三条第三項において第二章から前章までの規定を適用しないこととされた処分、行政指導及び届出並びに命令等を定める行為に関する手続について、この法律の規定の趣旨にのっとり、行政運営における公正の確保と透明性の向上を図るため必要な措置を講ずるよう努めなければならない。

      附　則

  （施行期日）
１　この法律は、公布の日から起算して一年を超えない範囲内において政令で定める日から施行する。

  （経過措置）
２　この法律の施行前に第十五条第一項又は第三十条の規定による通知に相当する行為がされた場合においては、当該通知に相当する行為に係る不利益処分の手続に関しては、第三章の規定にかかわらず、なお従前の例による。
３　この法律の施行前に、届出その他政令で定める行為（以下「届出等」という。）がされた後一定期間内に限りすることができることとされている不利益処分に係る当該届出等がされた場合においては、当該不利益処分に係る手続に関しては、第三章の規定にかかわらず、なお従前の例による。
４　前二項に定めるもののほか、この法律の施行に関して必要な経過措置は、政令で定める。

      附　則（平成一一年一二月八日法律第一五一号）　抄

  （施行期日）
第一条　この法律は、平成十二年四月一日から施行する。

  （経過措置）
第三条　民法の一部を改正する法律（平成十一年法律第百四十九号）附則第三条第三項の規定により従前の例によることとされる準禁治産者及びその保佐人に関するこの法律による改正規定の適用については、次に掲げる改正規定を除き、なお従前の例による。
  一から二十五まで　略

      附　則（平成一一年一二月二二日法律第一六〇号）　抄

  （施行期日）
第一条　この法律（第二条及び第三条を除く。）は、平成十三年一月六日から施行する。ただし、次の各号に掲げる規定は、当該各号に定める日から施行する。
  一　第九百九十五条（核原料物質、核燃料物質及び原子炉の規制に関する法律の一部を改正する法律附則の改正規定に係る部分に限る。）、第千三百五条、第千三百六条、第千三百二十四条第二項、第千三百二十六条第二項及び第千三百四十四条の規定　公布の日

      附　則（平成一四年一二月一三日法律第一五二号）　抄

  （施行期日）
第一条　この法律は、行政手続等における情報通信の技術の利用に関する法律（平成十四年法律第百五十一号）の施行の日から施行する。

  （その他の経過措置の政令への委任）
第五条　前三条に定めるもののほか、この法律の施行に関し必要な経過措置は、政令で定める。

      附　則（平成一五年七月一六日法律第一一九号）　抄

  （施行期日）
第一条　この法律は、地方独立行政法人法（平成十五年法律第百十八号）の施行の日から施行する。

      附　則（平成一七年六月二九日法律第七三号）　抄

  （施行期日）
第一条　この法律は、公布の日から起算して一年を超えない範囲内において政令で定める日から施行する。ただし、次条及び附則第八条の規定は、公布の日から施行する。

  （経過措置）
第二条　この法律による改正後の行政手続法（以下「新法」という。）第二条第八号に規定する命令等（以下この条において「命令等」という。）を定める機関（以下この条において「命令等制定機関」という。）は、命令等を定めようとするときは、この法律の施行前においても、新法第六章の規定の例によることができる。この場合において、同章の規定の例により実施した手続は、新法の適用については、当該命令等制定機関が同章の規定により実施したものとみなす。
２　前項の規定の適用がある場合を除き、命令等制定機関がこの法律の施行の日から六十日以内に定める命令等については、新法第六章の規定は、適用しない。

      附　則（平成一八年六月八日法律第五八号）　抄

  （施行期日）
第一条　この法律は、公布の日から起算して一年を超えない範囲内において政令で定める日から施行する。

      附　則（平成一八年六月一四日法律第六六号）　抄

この法律は、平成十八年証券取引法改正法の施行の日から施行する。

      附　則（平成二六年六月一三日法律第六九号）　抄

  （施行期日）
第一条　この法律は、行政不服審査法（平成二十六年法律第六十八号）の施行の日から施行する。

  （経過措置の原則）
第五条　行政庁の処分その他の行為又は不作為についての不服申立てであってこの法律の施行前にされた行政庁の処分その他の行為又はこの法律の施行前にされた申請に係る行政庁の不作為に係るものについては、この附則に特別の定めがある場合を除き、なお従前の例による。

  （訴訟に関する経過措置）
第六条　この法律による改正前の法律の規定により不服申立てに対する行政庁の裁決、決定その他の行為を経た後でなければ訴えを提起できないこととされる事項であって、当該不服申立てを提起しないでこの法律の施行前にこれを提起すべき期間を経過したもの（当該不服申立てが他の不服申立てに対する行政庁の裁決、決定その他の行為を経た後でなければ提起できないとされる場合にあっては、当該他の不服申立てを提起しないでこの法律の施行前にこれを提起すべき期間を経過したものを含む。）の訴えの提起については、なお従前の例による。
２　この法律の規定による改正前の法律の規定（前条の規定によりなお従前の例によることとされる場合を含む。）により異議申立てが提起された処分その他の行為であって、この法律の規定による改正後の法律の規定により審査請求に対する裁決を経た後でなければ取消しの訴えを提起することができないこととされるものの取消しの訴えの提起については、なお従前の例による。
３　不服申立てに対する行政庁の裁決、決定その他の行為の取消しの訴えであって、この法律の施行前に提起されたものについては、なお従前の例による。

  （その他の経過措置の政令への委任）
第十条　附則第五条から前条までに定めるもののほか、この法律の施行に関し必要な経過措置（罰則に関する経過措置を含む。）は、政令で定める。

      附　則（平成二六年六月一三日法律第七〇号）　抄

  （施行期日）
第一条　この法律は、平成二十七年四月一日から施行する。
`.replace(/\n/g, "\r\n").replace(/\r\r/g, "\r");