.law .law-title {
    font-weight: bold;
}

.law .law-num {
    font-weight: bold;
}

.law .enact-statement {
    margin-top: 1em;
    text-indent: 1em;
}

.law .toc {
    margin-top: 1em;
}

.law .toc-group {
    padding-left: 1em;
}

.law .article-group-title {
    font-weight: bold;
    margin-top: 1em;
}

.law .article {
    margin-top: 1em;
}

.law .article-caption {
    margin-left: 1em;
    padding-left: 1em;
    text-indent: -1em;
}

.law .article-title {
    font-weight: bold;
}

.law .paragraph-item-caption {
    margin-left: 1em;
    padding-left: 1em;
    text-indent: -1em;
}

.law .paragraph-item-body {
    padding-left: 1em;
    text-indent: -1em;
}

.law .paragraph-item-num {
    font-weight: bold;
}

.law .indent-first-line {
    text-indent: 1em;
}

.law .appdx_table {
    margin-top: 1em;
}

.law .appdx_table_title {
    font-weight: bold;
}

.law .appdx_table_body {
    padding-left: 1em;
}

.law .appdx_style {
    margin-top: 1em;
}

.law .appdx_style_title {
    font-weight: bold;
}

.law .appdx_style_body {
    padding-left: 1em;
}

.law .list {
    text-indent: 0;
    padding-left: 1em;
}

.law table {
    border-collapse: collapse;
    text-indent: 0;
}

.law td {
    border: 1px solid black;
}

.law pre {
    white-space: pre-wrap;
}
